@@ -5,7 +5,7 @@ from datetime import datetime, timedelta
 from pathlib import Path
 import requests
 from netsuite.NetsuiteToken import NetsuiteToken
-from netsuite.swagger_client.rest_client import RestClient
+from netsuite.swagger_client.rest_client import RestClient, QueryClient
 from netsuite.settings import APISettings
 from netsuite.storages import BaseStorage, JSONStorage
 
@@ -15,6 +15,7 @@ class Netsuite:
     storage: BaseStorage = None
     api_settings: APISettings
     rest_client = None
+    query_client = None
 
     def __init__(self, config: dict = None, config_file: Path = None):
         if config and config_file:
@@ -52,6 +53,7 @@ class Netsuite:
         self.rest_url = f"https://{self.api_settings.NETSUITE_APP_NAME}.suitetalk.api.netsuite.com/services/rest" \
                         f"/record/v1/ "
         self.access_token_url = f"https://{self.api_settings.NETSUITE_APP_NAME}.suitetalk.api.netsuite.com/services/rest/auth/oauth2/v1/token",
+        self.status_dict = None
 
     @property
     def REST_CLIENT(self):
@@ -59,6 +61,12 @@ class Netsuite:
             self.rest_client = RestClient(self)
         return self.rest_client
 
+    @property
+    def QUERY_CLIENT(self):
+        if not self.query_client:
+            self.query_client=QueryClient(self)
+        return self.query_client
+
     @property
     def token(self) -> NetsuiteToken:
         return self.storage.get_token(self.app_name)
@@ -111,3 +119,20 @@ class Netsuite:
             raise Exception(f"{app_name} does not have a token in storage, please authenticate")
         # self.rest_v1 = REST_V1(self)
         self.rest_client = RestClient(self)
+
+    def get_token(self):
+        if not self.token.is_expired:
+            return self.token
+        else:
+            return self.request_access_token()
+
+    def get_status_dict(self):
+        if self.status_dict is None:
+            query = "SELECT * FROM EntityStatus WHERE inactive = 'F'"
+            statuses = self.QUERY_CLIENT.query_api.execute_query(query=query)
+            status_dict = {}
+            for status in statuses:
+                status_dict[f"{status.get('entitytype').upper()}-{status.get('name').upper()}"] = status.get('key')
+            self.statuses = status_dict
+
+        return self.statuses
\ No newline at end of file
